import {
  IonButton,
  IonButtons,
  IonContent,
  IonItem,
  IonList,
  IonModal,
  IonTitle,
  IonToolbar,
} from '@ionic/react';
import React, { Fragment, useRef } from 'react';
import { useFind } from 'react-pouchdb';
import { enterAnimation, leaveAnimation } from '../../lib/animation';
import phoneRoute from '../../theme/icons/font-gis/svg/routing/uEB08-phone-route-nons.svg';

const TrackBrowser: React.FC<{}> = () => {
  const gpxes = useFind({
    selector: {
      type: 'gpx',
    },
  });

  const modal = useRef<HTMLIonModalElement>(null);

  const dismiss = () => {
    modal.current?.dismiss();
  };

  return (
    <Fragment>
      <IonButton id='track-browser-button'>
        <img src={phoneRoute} alt='GPS tracks' width='24px' />
      </IonButton>
      <IonModal
        ref={modal}
        trigger='track-browser-button'
        enterAnimation={enterAnimation}
        leaveAnimation={leaveAnimation}
      >
        <IonToolbar>
          <IonTitle>Tracks</IonTitle>
          <IonButtons slot='end'>
            <IonButton onClick={() => dismiss()}>Close</IonButton>
          </IonButtons>
        </IonToolbar>
        <IonContent>
          <IonList>
            {gpxes.map((gpx: any) => {
              return <IonItem key={gpx._id}>
                <span>{gpx.gpx.metadata.time}</span>
              </IonItem>;
            })}
          </IonList>
        </IonContent>
      </IonModal>
    </Fragment>
  );
};

export default TrackBrowser;
